@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.10   2021/06/06
+ * Version: 0.2.11   2023/05/27
  */
 
 #include "caitsith.h"
@@ -970,6 +970,10 @@ int cs_start_execve(struct linux_binprm *bprm, struct cs_request_info **rp)
 	r->tmp = NULL;
 	kfree(r->dump.data);
 	r->dump.data = NULL;
+	if (retval) {
+		cs_finish_execve(-1, r);
+		*rp = NULL;
+	}
 	return retval;
 }
 
