@@ -61,3 +61,7 @@ void * __init probe_d_absolute_path(void);
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
 void * __init probe_ksize(void);
 #endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+void * __init probe_copy_to_kernel_nofault(void);
+#endif
